# -*- coding: utf-8 -*-

from Products.ATContentTypes.interfaces import IATContentType
from Products.Archetypes import atapi
from archetypes.referencebrowserwidget import ReferenceBrowserWidget
from archetypes.schemaextender.field import ExtensionField
from archetypes.schemaextender.interfaces import ISchemaExtender
from zope.component import adapts
from zope.interface import implements


class BlobLinesField(ExtensionField, atapi.LinesField):
     """A trivial field."""

class BlobStringField(ExtensionField, atapi.StringField):
     """A trivial field."""


class FooExtender(object):
    adapts(IATContentType)
    implements(ISchemaExtender)

    fields = [
        BlobStringField("foo_field",
            widget = ReferenceBrowserWidget(
                label="Useless, invisible field",
                visible={'view': 'invisible', 'edit': 'invisible'},
            ),
        ),
        BlobLinesField("foo_multivalued_field",
            multiValued=True,
            widget = ReferenceBrowserWidget(
                label="Useless, invisible multivalued field",
                visible={'view': 'invisible', 'edit': 'invisible'},
            ),
        ),
        ]

    def __init__(self, context):
        self.context = context

    def getFields(self):
        return self.fields



# -*- coding: utf-8 -*-

import json
from Products.Five.browser import BrowserView

class OutputView(BrowserView):
    
    def __call__(self, *args, **kwargs):
        form = self.request.form
        self.request.response.setHeader('Content-Type', 'text/plain')
        return form.items()

class VocabView(BrowserView):
    
    def __call__(self, *args, **kwargs):
        response = self.request.response
        response.setHeader("Content-type", "application/json")
        response.write(json.dumps([
                                   {'value': 'aaa',
                                    'label': 'Aaa',
                                   },
                                   {'value': 'bbb',
                                    'label': 'Bbb',
                                   },
                                   {'value': 'ccc',
                                    'label': 'Ccc',
                                   },                                   
                                   ]))



from setuptools import setup, find_packages
import os

version = '0.2.1'

setup(name='rt.zptformfield',
      version=version,
      description="Some ZPT macros for Zope/Plone HTML forms development",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.rst")).read(),
      # Get more strings from
      # http://pypi.python.org/pypi?:action=list_classifiers
      classifiers=[
        "Development Status :: 4 - Beta",
        "Framework :: Plone",
        "Framework :: Plone :: 4.0",
        "Framework :: Plone :: 4.1",
        "Framework :: Plone :: 4.2",
        "Framework :: Plone :: 4.3",
        "Framework :: Zope2",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        ],
      keywords='plone zpt zope form macro',
      author='RedTurtle Technology',
      author_email='sviluppoplone@redturtle.it',
      url='http://github.com/RedTurtle/rt.zptformfield',
      license='GPL',
      namespace_packages=['rt'],
      packages=find_packages('src', exclude=['ez_setup']),
      package_dir={'': 'src'},
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
      ],
      entry_points="""
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )
